@@ -66,17 +66,14 @@ class PatchPrimaryTab(tabs.PrimaryTab):
         super(PatchPrimaryTab, self).render_entity_attributes(entity)
         self.w(u'<h4>%s</h4>' % self._cw._('Patch revisions'))
         rset = self._cw.execute(
-            'Any R,RA,RB,RC,RD,R, R ORDERBY RC DESC '
+            'Any R,RA,RB,RC,RD,R ORDERBY RC DESC '
             'WHERE X eid %(x)s, X patch_revision R,'
             'R author RA, R branch RB, R creation_date RC, R description RD',
             {'x': entity.eid})
         _, __ = self._cw._, self._cw.__
         self.wview('table', rset,
                    headers=[__('Revision'), __('author'), __('branch'),
-                            __('creation_date'), __('commit message'),
-                            _('nb comments')],
-                   cellvids={#0: 'vcreview.fileversion',
-                             5: 'vcreview.revcommentcount'})
+                            __('creation_date'), __('commit message')])
 
 class PatchHeadTab(EntityView):
     """Revision view of the tip most version of the patch
@@ -91,16 +88,6 @@ class PatchHeadTab(EntityView):
             tip.view('primary', w=self.w)
 
 
-class RevCommentCount(EntityView):
-    __regid__ = 'vcreview.revcommentcount'
-    __select__ = is_instance('Revision')
-
-    def cell_call(self, row, col):
-        count = self._cw.execute(
-            'Any COUNT(C) WHERE IP point_of RE, C comments IP, RE eid %(x)s',
-            {'x': self.cw_rset[row][col]})[0][0]
-        self.w(unicode(count))
-
 #_pvs.tag_object_of(('*', 'patch_revision', '*'), 'hidden') # in breadcrumbs
 
 # repository primary view ######################################################
